==> haskell-interpolatedstring-perl6-1.0.2-175-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-JFKh2M9tnvpJGPQlkMncSh
key:                  interpolatedstring-perl6-1.0.2-JFKh2M9tnvpJGPQlkMncSh
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  d0f5e92003a602e3969d5cf17b3836bc
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.0.1/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-JFKh2M9tnvpJGPQlkMncSh
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    haskell-src-meta-0.8.7-6hN0eMsTJXk5N5bLTvYzf8
    template-haskell-2.17.0.0 text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.2-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 interpolatedstring-perl6
version:              1.0.2
visibility:           public
id:                   interpolatedstring-perl6-1.0.2-3Xex2y11MhAB3jx3CCc1AT
key:                  interpolatedstring-perl6-1.0.2-3Xex2y11MhAB3jx3CCc1AT
license:              LicenseRef-PublicDomain
copyright:            Audrey Tang
maintainer:           Audrey Tang <audreyt@audreyt.org>
author:               Audrey Tang
stability:            stable
synopsis:             QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.

category:             Data
abi:                  4c1a39c572b96fc94e91d40e55832bf9
exposed:              True
exposed-modules:      Text.InterpolatedString.Perl6
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/interpolatedstring-perl6-1.0.2

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/interpolatedstring-perl6-1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-interpolatedstring-perl6
hs-libraries:         HSinterpolatedstring-perl6-1.0.2-3Xex2y11MhAB3jx3CCc1AT
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    haskell-src-meta-0.8.7-8KuOrB5dB7F1Q7FNBExh02
    template-haskell-2.17.0.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock

haddock-html:         /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
